@@ -29,6 +29,7 @@ if ($m_nRight < 1) {
     print div({align => 'center'}, translate('Failednotindatabase'))     if $m_nSkipCaptch eq -2;
     print div({align => 'center'}, translate('Failedinvalidcode'))       if $m_nSkipCaptch eq -3;
     my $register = translate('register');
+    my $t_forgetPass = translate('forgetPass');
     print qq(
     <div class="dbForm">
     <form  name="login" id="loginForm" class="dbForm" target="_parent" method="get" name="Login"  onsubmit="m_sid ='123';submitForm(this,'login','login');return false;">
@@ -45,6 +46,7 @@ if ($m_nRight < 1) {
     <br/>
     <a href="javascript:requestURI('$m_hrSettings->{cgi}{serverName}$ENV{SCRIPT_NAME}?action=reg','register','register');">$register</a>
     <br/>
+    <a href="javascript:requestURI('$m_hrSettings->{cgi}{serverName}$ENV{SCRIPT_NAME}?action=lostPassword','lostPassword','lostPassword')">$t_forgetPass</a>
     </div>);
 } else {
     my $lg =
@@ -53,4 +55,8 @@ if ($m_nRight < 1) {
     my $logout  = translate('logout');
     print qq ($welcome, $m_sUser <br/><a  class="link" href="$lg">$logout</a><br/>);
 }
+
+
+
+
 1;
