@@ -1,59 +1,59 @@
 $VAR1 = {
-          'uploads' => {
-                         'right' => 2,
-                         'enabled' => 1,
-                         'maxlength' => '2100000000000000',
-                         'chmod' => 438,
-                         'path' => '/var/www/htdocs//download'
-                       },
-          'tree' => {
-                      'navigation' => '/var/www/cgi-bin/config/tree.pl',
-                      'links' => '/var/www/cgi-bin/config/links.pl'
-                    },
-          'apacheconfig' => '/etc/apache2/sites-enabled/',
-          'saveTranslate' => '0',
-          'config' => '/var/www/cgi-bin/config/settings.pl',
-          'size' => '16',
-          'news' => {
-                      'right' => 5,
-                      'messages' => '5',
-                      'captcha' => 3
-                    },
-          'mod' => 'n',
-          'version' => '1.08',
-          'htmlright' => '2',
-          'cgi' => {
-                     'title' => 'MySQL::Admin',
-                     'bin' => '/var/www/cgi-bin',
-                     'serverName' => 'http://localhost',
-                     'expires' => '+1y',
-                     'cookiePath' => '/',
-                     'DocumentRoot' => '/var/www/htdocs/',
-                     'style' => 'mysql'
-                   },
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
           'files' => {
-                       'chmod' => '0755',
                        'owner' => 'lze',
+                       'chmod' => '0755',
                        'group' => 'lze'
                      },
+          'tree' => {
+                      'links' => '/var/www/cgi-bin/config/links.pl',
+                      'navigation' => '/var/www/cgi-bin/config/tree.pl'
+                    },
           'language' => 'en',
-          'admin' => {
-                       'password' => 'testpass'
-                     },
+          'database' => {
+                          'CurrentUser' => 'root',
+                          'host' => 'localhost',
+                          'password' => '',
+                          'CurrentHost' => 'localhost',
+                          'CurrentDb' => 'MySQLAdmin',
+                          'user' => 'root',
+                          'name' => 'MySQLAdmin',
+                          'CurrentPass' => ''
+                        },
           'translate' => '/var/www/cgi-bin/config/translate.pl',
           'defaultAction' => 'ShowDatabases',
+          'mod' => 'n',
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'news' => {
+                      'captcha' => 3,
+                      'messages' => '5',
+                      'right' => 5
+                    },
+          'version' => '1.09',
           'floodtime' => 10,
-          'database' => {
-                          'CurrentHost' => 'localhost',
-                          'name' => 'MySQLAdmin',
-                          'CurrentPass' => '',
-                          'CurrentUser' => 'root',
-                          'password' => '',
-                          'host' => 'localhost',
-                          'user' => 'root',
-                          'CurrentDb' => 'MySQLAdmin'
-                        }
+          'saveTranslate' => '0',
+          'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'cgi' => {
+                     'serverName' => 'http://localhost',
+                     'style' => 'mysql',
+                     'cookiePath' => '/',
+                     'expires' => '+1y',
+                     'DocumentRoot' => '/var/www/htdocs/',
+                     'title' => 'MySQL::Admin',
+                     'bin' => '/var/www/cgi-bin'
+                   },
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'htmlright' => '2',
+          'uploads' => {
+                         'path' => '/var/www/htdocs//download',
+                         'chmod' => 438,
+                         'right' => 2,
+                         'enabled' => 1,
+                         'maxlength' => '2100000000000000'
+                       },
+          'size' => '16',
+          'admin' => {
+                       'password' => 'testpass'
+                     }
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
